@@ -1,3 +1,12 @@
+"""
+Convert an OPTIMADE structure, in the format of
+[`StructureResource`][optimade.models.structures.StructureResource]
+to an ASE `Atoms` object.
+
+This conversion function relies on the ASE code.
+
+For more information on the ASE code see [their documentation](https://wiki.fysik.dtu.dk/ase/).
+"""
 from typing import Dict
 from warnings import warn
 
@@ -10,7 +19,7 @@ from optimade.adapters.exceptions import ConversionError
 try:
     from ase import Atoms, Atom
 except (ImportError, ModuleNotFoundError):
-    Atoms = None
+    Atoms = type("Atoms", (), {})
     ASE_NOT_FOUND = "ASE not found, cannot convert structure to an ASE Atoms"
 
 
@@ -18,14 +27,19 @@ __all__ = ("get_ase_atoms",)
 
 
 def get_ase_atoms(optimade_structure: OptimadeStructure) -> Atoms:
-    """ Get ASE Atoms from OPTIMADE structure
+    """ Get ASE `Atoms` from OPTIMADE structure.
 
-    NOTE: Cannot handle partial occupancies (this includes vacancies)
+    Caution:
+        Cannot handle partial occupancies (this includes vacancies).
+
+    Parameters:
+        optimade_structure: OPTIMADE structure.
+
+    Returns:
+        ASE `Atoms` object.
 
-    :param optimade_structure: OPTIMADE structure
-    :return: ASE.Atoms
     """
-    if globals().get("Atoms", None) is None:
+    if "optimade.adapters" in repr(globals().get("Atoms")):
         warn(ASE_NOT_FOUND)
         return None
 
