@@ -20,7 +20,13 @@ class TypedRelationship(Relationship):
     # This may be updated when moving to Python 3.8
     @validator("data")
     def check_rel_type(cls, data):
-        if hasattr(cls, "_req_type") and any(obj.type != cls._req_type for obj in data):
+        if not isinstance(data, list):
+            # All relationships at this point are empty-to-many relationships in JSON:API:
+            # https://jsonapi.org/format/1.0/#document-resource-object-linkage
+            raise ValueError("`data` key in a relationship must always store a list.")
+        if hasattr(cls, "_req_type") and any(
+            getattr(obj, "type", None) != cls._req_type for obj in data
+        ):
             raise ValueError("Object stored in relationship data has wrong type")
         return data
 
@@ -82,6 +88,7 @@ class EntryResourceAttributes(Attributes):
 
 
 class EntryResource(Resource):
+    """The base model for an entry resource."""
 
     id: str = Field(
         ...,
@@ -139,6 +146,7 @@ class EntryInfoProperty(BaseModel):
     unit: Optional[str] = Field(
         None,
         description="""The physical unit of the entry property.
+This MUST be a valid representation of units according to version 2.1 of [The Unified Code for Units of Measure](https://unitsofmeasure.org/ucum.html).
 It is RECOMMENDED that non-standard (non-SI) units are described in the description for the property.""",
     )
 
