@@ -1,6 +1,7 @@
 # pylint: disable=no-self-argument
+from enum import Enum
 import json
-import logging
+import warnings
 from typing import Optional, Dict, List
 
 try:
@@ -9,18 +10,30 @@ except ImportError:
     from typing_extensions import Literal
 from pathlib import Path
 
-from pydantic import BaseSettings, Field, root_validator
+from pydantic import (  # pylint: disable=no-name-in-module
+    BaseSettings,
+    Field,
+    root_validator,
+    AnyHttpUrl,
+    validator,
+)
 
 from optimade import __version__
 from optimade.models import Implementation, Provider
 
 
 DEFAULT_CONFIG_FILE_PATH = str(Path.home().joinpath(".optimade.json"))
-logger = logging.getLogger("optimade")
 
 
-class NoFallback(Exception):
-    """No fallback value can be found."""
+class LogLevel(Enum):
+    """Replication of logging LogLevels"""
+
+    NOTSET = "notset"
+    DEBUG = "debug"
+    INFO = "info"
+    WARNING = "warning"
+    ERROR = "error"
+    CRITICAL = "critical"
 
 
 class ServerConfig(BaseSettings):
@@ -29,8 +42,8 @@ class ServerConfig(BaseSettings):
 
     """
 
-    config_file: str = Field(
-        DEFAULT_CONFIG_FILE_PATH, description="File to load alternative defaults from",
+    config_file: Optional[str] = Field(
+        None, description="File to load alternative defaults from",
     )
     debug: bool = Field(
         False, description="Turns on Debug Mode for the OPTIMADE Server implementation"
@@ -66,20 +79,23 @@ class ServerConfig(BaseSettings):
     )
     implementation: Implementation = Field(
         Implementation(
-            name="Optimade Python Tools",
+            name="OPTIMADE Python Tools",
             version=__version__,
             source_url="https://github.com/Materials-Consortia/optimade-python-tools",
             maintainer={"email": "dev@optimade.org"},
         ),
         description="Introspective information about this OPTIMADE implementation",
     )
+    index_base_url: Optional[AnyHttpUrl] = Field(
+        None,
+        description="An optional link to the base URL for the index meta-database of the provider.",
+    )
     provider: Provider = Field(
         Provider(
             prefix="exmpl",
             name="Example provider",
             description="Provider used for examples, not to be assigned to a real database",
             homepage="https://example.com",
-            index_base_url="http://localhost:5001",
         ),
         description="General information about the provider of this OPTIMADE implementation",
     )
@@ -93,7 +109,6 @@ class ServerConfig(BaseSettings):
         {},
         description="A mapping between field names in the database with their corresponding OPTIMADE field names, broken down by endpoint.",
     )
-
     length_aliases: Dict[
         Literal["links", "references", "structures"], Dict[str, str]
     ] = Field(
@@ -104,36 +119,72 @@ class ServerConfig(BaseSettings):
             "API fields, not the database fields."
         ),
     )
-
     index_links_path: Path = Field(
         Path(__file__).parent.joinpath("index_links.json"),
         description="Absolute path to a JSON file containing the MongoDB collection of /links resources for the index meta-database",
     )
+    log_level: LogLevel = Field(
+        LogLevel.INFO, description="Logging level for the OPTIMADE server."
+    )
+    log_dir: Path = Field(
+        Path("/var/log/optimade/"),
+        description="Folder in which log files will be saved.",
+    )
+
+    @validator("implementation", pre=True)
+    def set_implementation_version(cls, v):
+        """Set defaults and modify bypassed value(s)"""
+        res = {"version": __version__}
+        res.update(v)
+        return res
 
     @root_validator(pre=True)
-    def load_default_settings(cls, values):  # pylint: disable=no-self-argument
+    def load_settings(cls, values):
         """
-        Loads settings from a root file if available and uses that as defaults in
-        place of built in defaults
+        Loads settings from a JSON config file, if available, and uses them in place
+        of the built-in defaults.
         """
         config_file_path = Path(values.get("config_file", DEFAULT_CONFIG_FILE_PATH))
 
         new_values = {}
 
-        if config_file_path.exists() and config_file_path.is_file():
-            logger.debug("Found config file at: %s", config_file_path)
-            with open(config_file_path) as f:
-                new_values = json.load(f)
+        if config_file_path.is_file():
+            try:
+                with open(config_file_path) as f:
+                    new_values = json.load(f)
+            except json.JSONDecodeError as exc:
+                warnings.warn(
+                    f"Unable to parse config file {config_file_path} as JSON. Error: {exc}."
+                )
+
         else:
-            logger.debug(  # pragma: no cover
-                "Did not find config file at: %s", config_file_path
-            )
+            if DEFAULT_CONFIG_FILE_PATH != str(config_file_path):
+                warnings.warn(
+                    f"Unable to find config file in requested location {config_file_path}, "
+                    "using the built-in default settings instead."
+                )
+            else:
+                warnings.warn(
+                    f"Unable to find config file in default location {DEFAULT_CONFIG_FILE_PATH}, "
+                    "using the built-in default settings instead."
+                )
+
+        if not new_values:
+            values["config_file"] = None
 
         new_values.update(values)
 
         return new_values
 
     class Config:
+        """
+        This is a pydantic model Config object that modifies the behaviour of
+        ServerConfig by adding a prefix to the environment variables that
+        override config file values. It has nothing to do with the OPTIMADE
+        config.
+
+        """
+
         env_prefix = "optimade_"
 
 
