@@ -1,5 +1,12 @@
-# pylint: disable=line-too-long
+"""The OPTIMADE Index Meta-Database server
+
+The server is based on MongoDB, using either `pymongo` or `mongomock`.
+
+This is an example implementation with example data.
+To implement your own index meta-database server see the documentation at https://optimade.org/optimade-python-tools.
+"""
 import json
+import warnings
 
 from lark.exceptions import VisitError
 
@@ -8,17 +15,33 @@ from fastapi import FastAPI
 from fastapi.exceptions import RequestValidationError, StarletteHTTPException
 from fastapi.middleware.cors import CORSMiddleware
 
+with warnings.catch_warnings(record=True) as w:
+    from optimade.server.config import CONFIG
+
+    config_warnings = w
+
 from optimade import __api_version__, __version__
 import optimade.server.exception_handlers as exc_handlers
+from optimade.server.logger import LOGGER
+from optimade.server.middleware import (
+    AddWarnings,
+    CheckWronglyVersionedBaseUrls,
+    EnsureQueryParamIntegrity,
+    HandleApiHint,
+)
+from optimade.server.routers import index_info, links, versions
+from optimade.server.routers.utils import BASE_URL_PREFIXES
 
-from .config import CONFIG
-from .middleware import EnsureQueryParamIntegrity
-from .routers import index_info, links
-from .routers.utils import BASE_URL_PREFIXES
-
+if CONFIG.config_file is None:
+    LOGGER.warn(
+        f"Invalid config file or no config file provided, running server with default settings. Errors: "
+        f"{[warnings.formatwarning(w.message, w.category, w.filename, w.lineno, '') for w in config_warnings]}"
+    )
+else:
+    LOGGER.info(f"Loaded settings from {CONFIG.config_file}.")
 
 if CONFIG.debug:  # pragma: no cover
-    print("DEBUG MODE")
+    LOGGER.info("DEBUG MODE")
 
 
 app = FastAPI(
@@ -41,7 +64,7 @@ if not CONFIG.use_real_mongo and CONFIG.index_links_path.exists():
     from .routers.links import links_coll
     from .routers.utils import mongo_id_for_database
 
-    print("loading index links...")
+    LOGGER.debug("Loading index links...")
     with open(CONFIG.index_links_path) as f:
         data = json.load(f)
 
@@ -51,16 +74,19 @@ if not CONFIG.use_real_mongo and CONFIG.index_links_path.exists():
             db["_id"] = {"$oid": mongo_id_for_database(db["id"], db["type"])}
             processed.append(db)
 
-        print("inserting index links into collection...")
+        LOGGER.debug("Inserting index links into collection...")
         links_coll.collection.insert_many(
             bson.json_util.loads(bson.json_util.dumps(processed))
         )
-        print("done inserting index links...")
+        LOGGER.debug("Done inserting index links...")
 
 
 # Add various middleware
 app.add_middleware(CORSMiddleware, allow_origins=["*"])
 app.add_middleware(EnsureQueryParamIntegrity)
+app.add_middleware(CheckWronglyVersionedBaseUrls)
+app.add_middleware(HandleApiHint)
+app.add_middleware(AddWarnings)
 
 
 # Add various exception handlers
@@ -73,9 +99,15 @@ app.add_exception_handler(VisitError, exc_handlers.grammar_not_implemented_handl
 app.add_exception_handler(Exception, exc_handlers.general_exception_handler)
 
 
-# Add various endpoints to `/vMAJOR`
-app.include_router(index_info.router, prefix=BASE_URL_PREFIXES["major"])
-app.include_router(links.router, prefix=BASE_URL_PREFIXES["major"])
+# Add all endpoints to unversioned URL
+for endpoint in (index_info, links, versions):
+    app.include_router(endpoint.router)
+
+
+def add_major_version_base_url(app: FastAPI):
+    """ Add mandatory endpoints to `/vMAJOR` base URL. """
+    for endpoint in (index_info, links):
+        app.include_router(endpoint.router, prefix=BASE_URL_PREFIXES["major"])
 
 
 def add_optional_versioned_base_urls(app: FastAPI):
@@ -92,5 +124,7 @@ def add_optional_versioned_base_urls(app: FastAPI):
 
 @app.on_event("startup")
 async def startup_event():
+    # Add API endpoints for MANDATORY base URL `/vMAJOR`
+    add_major_version_base_url(app)
     # Add API endpoints for OPTIONAL base URLs `/vMAJOR.MINOR` and `/vMAJOR.MINOR.PATCH`
     add_optional_versioned_base_urls(app)
