@@ -1,11 +1,12 @@
-from typing import Tuple
+from typing import Tuple, Optional
 from optimade.server.config import CONFIG
 
 __all__ = ("BaseResourceMapper",)
 
 
 class BaseResourceMapper:
-    """ Generic Resource Mapper that defines and performs the mapping
+    """
+    Generic Resource Mapper that defines and performs the mapping
     between objects in the database and the resource objects defined by
     the specification.
 
@@ -41,7 +42,7 @@ class BaseResourceMapper:
         those defined by the server config.
 
         Returns:
-            Tuple[Tuple[str, str]]: a tuple of alias tuples.
+            A tuple of alias tuples.
 
         """
         return (
@@ -63,7 +64,7 @@ class BaseResourceMapper:
         those defined by the server config.
 
         Returns:
-            Tuple[Tuple[str, str]]: a tuple of length alias tuples.
+            A tuple of length alias tuples.
 
         """
         return cls.LENGTH_ALIASES + tuple(
@@ -71,10 +72,16 @@ class BaseResourceMapper:
         )
 
     @classmethod
-    def length_alias_for(cls, field: str) -> str:
+    def length_alias_for(cls, field: str) -> Optional[str]:
         """ Returns the length alias for the particular field, or `None` if no
         such alias is found.
 
+        Parameters:
+            field: OPTIMADE field name.
+
+        Returns:
+            Aliased field as found in [`all_length_aliases()`][optimade.server.mappers.entries.BaseResourceMapper.all_length_aliases].
+
         """
         return dict(cls.all_length_aliases()).get(field, None)
 
@@ -82,11 +89,12 @@ class BaseResourceMapper:
     def alias_for(cls, field: str) -> str:
         """Return aliased field name.
 
-        :param field: OPTIMADE field name
-        :type field: str
+        Parameters:
+            field: OPTIMADE field name.
+
+        Returns:
+            Aliased field as found in [`all_aliases()`][optimade.server.mappers.entries.BaseResourceMapper.all_aliases].
 
-        :return: Aliased field as found in PROVIDER_ALIASES + ALIASES
-        :rtype: str
         """
         split = field.split(".")
         alias = dict(cls.all_aliases()).get(split[0], None)
@@ -94,28 +102,48 @@ class BaseResourceMapper:
             return alias + ("." + ".".join(split[1:]) if len(split) > 1 else "")
         return field
 
+    @classmethod
+    def alias_of(cls, field: str) -> str:
+        """ Return de-aliased field name, if it exists,
+        otherwise return the input field name.
+
+        Args:
+            field: Field name to be de-aliased.
+
+        Returns:
+            De-aliased field name, falling back to returning `field`.
+
+        """
+        field = field.split(".")[0]
+        return {alias: real for real, alias in cls.all_aliases()}.get(field, field)
+
     @classmethod
     def get_required_fields(cls) -> set:
-        """Return set REQUIRED response fields"""
+        """Get REQUIRED response fields.
+
+        Returns:
+            REQUIRED response fields.
+
+        """
         res = cls.TOP_LEVEL_NON_ATTRIBUTES_FIELDS.copy()
         res.update(cls.REQUIRED_FIELDS)
         return res
 
     @classmethod
     def map_back(cls, doc: dict) -> dict:
-        """Map properties from MongoDB to OPTIMADE
+        """Map properties from MongoDB to OPTIMADE.
 
-        Starting from a MongoDB document ``doc``, map the DB fields to the corresponding OPTIMADE fields.
+        Starting from a MongoDB document `doc`, map the DB fields to the corresponding OPTIMADE fields.
         Then, the fields are all added to the top-level field "attributes",
-        with the exception of other top-level fields, defined in ``cls.TOPLEVEL_NON_ATTRIBUTES_FIELDS``.
-        All fields not in ``cls.TOPLEVEL_NON_ATTRIBUTES_FIELDS`` + "attributes" will be removed.
-        Finally, the ``type`` is given the value of the specified ``cls.ENDPOINT``.
+        with the exception of other top-level fields, defined in `cls.TOP_LEVEL_NON_ATTRIBUTES_FIELDS`.
+        All fields not in `cls.TOP_LEVEL_NON_ATTRIBUTES_FIELDS` + "attributes" will be removed.
+        Finally, the `type` is given the value of the specified `cls.ENDPOINT`.
 
-        :param doc: A resource object in MongoDB format
-        :type doc: dict
+        Parameters:
+            doc: A resource object in MongoDB format.
 
-        :return: A resource object in OPTIMADE format
-        :rtype: dict
+        Returns:
+            A resource object in OPTIMADE format.
 
         """
         if "_id" in doc:
