@@ -5,6 +5,7 @@ from datetime import datetime
 from typing import Union, List, Dict
 
 from fastapi import HTTPException, Request
+from starlette.datastructures import URL as StarletteURL
 
 from optimade import __api_version__
 from optimade.models import (
@@ -144,8 +145,8 @@ def get_included_relationships(
             if entry_relationship is not None:
                 refs = entry_relationship.get("data", [])
                 for ref in refs:
-                    # could check here and raise a warning if any IDs clash
-                    endpoint_includes[entry_type][ref["id"]] = ref
+                    if ref["id"] not in endpoint_includes[entry_type]:
+                        endpoint_includes[entry_type][ref["id"]] = ref
 
     included = {}
     for entry_type in endpoint_includes:
@@ -169,7 +170,11 @@ def get_included_relationships(
     return [obj for endp in included.values() for obj in endp]
 
 
-def get_base_url(parsed_url_request: urllib.parse.ParseResult) -> str:
+def get_base_url(
+    parsed_url_request: Union[
+        urllib.parse.ParseResult, urllib.parse.SplitResult, StarletteURL
+    ]
+) -> str:
     """Get base URL for current server
 
     Take the base URL from the config file, if it exists, otherwise use the request.
